@@ -8,7 +8,7 @@ use Carp;
 use vars qw( $SOCKET_CLASS @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $SOCKS_ERROR $SOCKS5_RESOLVE $SOCKS4_RESOLVE $SOCKS_DEBUG %CODES );
 require Exporter;
 
-$VERSION = '0.69';
+$VERSION = '0.70';
 
 use constant {
 	SOCKS_WANT_READ  => 20,
@@ -129,7 +129,7 @@ use constant {
 
 $CODES{REPLY}->{&REQUEST_GRANTED}         = "request granted";
 $CODES{REPLY}->{&REQUEST_FAILED}          = "request rejected or failed";
-$CODES{REPLY}->{&REQUEST_REJECTED_IDENTD} = "request rejected becasue SOCKS server cannot connect to identd on the client";
+$CODES{REPLY}->{&REQUEST_REJECTED_IDENTD} = "request rejected because SOCKS server cannot connect to identd on the client";
 $CODES{REPLY}->{&REQUEST_REJECTED_USERID} = "request rejected because the client program and identd report different user-ids";
 
 # queue
@@ -158,7 +158,8 @@ sub new_from_fd {
 	
 	# do not allow to create new socket
 	local $CAN_CHANGE_SOCKET = 0;
-	return $sock->configure(\%arg);
+	$sock->configure(\%arg) || !$sock->blocking || return undef;
+	$sock;
 }
 
 *new_from_socket = \&new_from_fd;
@@ -417,9 +418,12 @@ sub _connect {
 			# IO::Socket::IP requires multiple connect calls
 			# when performing non-blocking multi-homed connect
 			unshift @{ ${*$self}->{SOCKS}->{queue} }, ['_socket_connect', [], undef, [], 0];
+			
+			# IO::Socket::IP::connect() returns false for non-blocking connections in progress
+			# IO::Socket::INET::connect() returns true for non-blocking connections in progress
+			# LOL
+			return; # connect() return value
 		}
-		
-		return; # connect() return value
 	}
 
 	return $self;
@@ -2428,7 +2432,7 @@ is.  The REPLY CODE is one of the constants as follows (integer value):
   For socks v4
   REQUEST_GRANTED(90): request granted
   REQUEST_FAILED(91): request rejected or failed
-  REQUEST_REJECTED_IDENTD(92): request rejected becasue SOCKS server cannot connect to identd on the client
+  REQUEST_REJECTED_IDENTD(92): request rejected because SOCKS server cannot connect to identd on the client
   REQUEST_REJECTED_USERID(93): request rejected because the client program and identd report different user-ids
   
   For socks v5
@@ -2488,7 +2492,7 @@ By default it tries to use C<IO::Socket::IP> 0.36+ as socket class. And falls
 back to C<IO::Socket::INET> if not available. You can set C<$IO::Socket::Socks::SOCKET_CLASS>
 before loading of C<IO::Socket::Socks> and then it will not try to detect proper base class
 itself. You can also set it after loading of C<IO::Socket::Socks> and this will automatically
-update C<@ISA>, so you shouldn't worry about inheritence.
+update C<@ISA>, so you shouldn't worry about inheritance.
 
 =head1 CONSTANTS
 
